@@ -6,7 +6,7 @@
 __author__ = 'Chris Miles'
 __copyright__ = '(c) Chris Miles 2006'
 __id__ = '$Id: linux_diskio.py 852 2006-07-21 16:23:55Z chris $'
-__url__ = '$URL: https://dev.eddie-tool.net/svn/eddie/trunk/eddietool/arch/Linux/linux_diskio/linux_diskio.py $'
+__url__ = '$URL: https://eddie-tool.googlecode.com/svn/eddie/trunk/eddietool/arch/Linux/linux_diskio/linux_diskio.py $'
 __version__ = '1.0'
 
 
