@@ -7,14 +7,14 @@ Start Date   : 20080513
 
 Description  : Eddie-Tool command-line entry points.
 
-$Id: commands.py 924 2009-03-02 07:41:52Z chris $
+$Id: commands.py 949 2009-09-07 07:24:01Z miles.chris $
 '''
 
 __copyright__ = 'Copyright (c) Chris Miles 2008'
 
 __author__ = 'Chris Miles'
 
-__url__ = 'http://eddie-tool.net/'
+__url__ = 'http://eddie-tool.psychofx.com/'
 
 __license__ = '''
     This program is free software; you can redistribute it and/or modify
@@ -343,7 +343,7 @@ def doArgs():
     usageMsg = "usage: %prog [options] eddie.cfg"
     versionMsg = """EDDIE Tool %s""" % __version__
     try:
-        versionMsg += " (Build %s)" %'$Revision: 924 $'.split()[1]
+        versionMsg += " (Build %s)" %'$Revision: 949 $'.split()[1]
     except:
         pass
 
@@ -421,7 +421,7 @@ def main():
     parseConfig.readConf(config_file, Config)
 
     try:
-        buildstr = " (Build %s)" %'$Revision: 924 $'.split()[1]
+        buildstr = " (Build %s)" %'$Revision: 949 $'.split()[1]
     except:
         buildstr = ''
     
